# oxmpl-py

Python bindings for the [OxMPL](https://github.com/juniorsundar/oxmpl) motion planning library.

## Documentation

For installation instructions, API reference, and usage examples, please refer to the **[Python API section](https://juniorsundar.github.io/oxmpl/python_api.html)** in the OxMPL Book.

## License

This project is licensed under the **BSD-3-Clause License**. See the [LICENSE](https://github.com/juniorsundar/oxmpl/blob/main/LICENSE) file for details.
